#
# spec file for package libxcrypt
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

%define major 1
%define libname %mklibname xcrypt %{major}
%define devellibname %mklibname xcrypt -d
%define staticlibname %mklibname xcrypt -d -s


Name:           libxcrypt
Version:        4.4.17
Release:        %mkrel 1
Summary:        Extended crypt library for DES, MD5, Blowfish and others
License:        GPL-3.0-or-later AND LGPL-2.1-or-later AND BSD-2-Clause AND BSD-3-Clause AND SUSE-Public-Domain
Group:          Development/C
URL:            https://github.com/besser82/%{name}
Source0:        https://github.com/besser82/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
# (tmb) temp force new gcc
BuildRequires:  gcc >= 10.1.0-1
# (tmb) force latest binutils
BuildRequires:  binutils >= 1:2.34-10


%description
libxcrypt is a modern library for one-way hashing of passwords.  It
supports DES, MD5, SHA-2-256, SHA-2-512, and bcrypt-based password
hashes, and provides the traditional Unix 'crypt' and 'crypt_r'
interfaces, as well as a set of extended interfaces pioneered by
Openwall Linux, 'crypt_rn', 'crypt_ra', 'crypt_gensalt',
'crypt_gensalt_rn', and 'crypt_gensalt_ra'.

%package -n %{libname}
Summary:        Extended crypt library for DES, MD5, Blowfish and others
License:        LGPL-2.1-or-later AND BSD-2-Clause AND BSD-3-Clause AND SUSE-Public-Domain
Group:          System/Libraries
Conflicts:      glibc < 6:2.28-2

%description -n %{libname}
libxcrypt is a modern library for one-way hashing of passwords.  It
supports DES, MD5, SHA-2-256, SHA-2-512, and bcrypt-based password
hashes, and provides the traditional Unix 'crypt' and 'crypt_r'
interfaces, as well as a set of extended interfaces pioneered by
Openwall Linux, 'crypt_rn', 'crypt_ra', 'crypt_gensalt',
'crypt_gensalt_rn', and 'crypt_gensalt_ra'.

%package -n %{devellibname}
Summary:        Development files for %{name}
License:        LGPL-2.1-or-later AND BSD-2-Clause AND BSD-3-Clause AND SUSE-Public-Domain
Group:          Development/C
Requires:       %{libname} = %{version}
Requires:       pkgconfig
Conflicts:      glibc-devel < 6:2.28-2
Provides:       %{name}-devel = %{version}-%{release}
Provides:       xcrypt-devel = %{version}-%{release}

%description  -n %{devellibname}
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package  -n %{staticlibname}
Summary:        Static library for -static linking with %{name}
License:        GPL-3.0-or-later AND LGPL-2.1-or-later AND BSD-2-Clause AND BSD-3-Clause AND SUSE-Public-Domain
Group:          Development/C
Requires:       %{devellibname} = %{version}
Requires:       glibc-static-devel
Conflicts:      glibc-static-devel < 6:2.28-2

%description -n %{staticlibname}
This package contains the libxcrypt static libraries for -static
linking.  You don't need this, unless you link statically, which
is highly discouraged.


%prep
%autosetup -p 1

%build
autoreconf -fiv
%configure           \
  --disable-silent-rules \
  --enable-shared        \
  --enable-static        \
  --enable-obsolete-api  \
  --enable-hashes=all    \
  --with-pkgconfigdir=%{_libdir}/pkgconfig
%make_build

%install
%make_install

find %{buildroot}%{_libdir} -name '*.la' -print -delete

%check
%make_build check || \
  {
    rc=$?;
    echo "-----BEGIN TESTLOG-----";
    cat test-suite.log;
    echo "-----END TESTLOG-----";
    exit $rc;
  }

%files -n %{libname}
%license COPYING.LIB LICENSING
%doc AUTHORS NEWS README.md THANKS
%{_libdir}/libcrypt.so.%{major}{,.*}
%{_libdir}/libowcrypt.so.%{major}

%files -n %{devellibname}
%doc TODO.md
%{_includedir}/crypt.h
%{_includedir}/xcrypt.h
%{_libdir}/libcrypt.so
%{_libdir}/libowcrypt.so
%{_libdir}/libxcrypt.so
%{_libdir}/pkgconfig/libcrypt.pc
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/man3/crypt.3.*
%{_mandir}/man3/crypt_checksalt.3.*
%{_mandir}/man3/crypt_gensalt.3.*
%{_mandir}/man3/crypt_gensalt_ra.3.*
%{_mandir}/man3/crypt_gensalt_rn.3.*
%{_mandir}/man3/crypt_preferred_method.3.*
%{_mandir}/man3/crypt_r.3.*
%{_mandir}/man3/crypt_ra.3.*
%{_mandir}/man3/crypt_rn.3.*
%{_mandir}/man5/crypt.5.*

%files -n %{staticlibname}
%{_libdir}/libcrypt.a
%{_libdir}/libowcrypt.a
%{_libdir}/libxcrypt.a


%changelog
* Sun Aug 23 2020 tv <tv> 4.4.17-1.mga8
+ Revision: 1618102
- 4.4.17

* Thu May 07 2020 tmb <tmb> 4.4.16-4.mga8
+ Revision: 1581510
- rebuild with gcc-10.1.0 final

* Mon May 04 2020 tmb <tmb> 4.4.16-2.mga8
+ Revision: 1579653
- rebuild with gcc 10.1

* Wed Apr 08 2020 luigiwalser <luigiwalser> 4.4.16-1.mga8
+ Revision: 1565494
- 4.4.16

* Thu Mar 05 2020 luigiwalser <luigiwalser> 4.4.15-1.mga8
+ Revision: 1553895
- 4.4.15

* Tue Feb 25 2020 luigiwalser <luigiwalser> 4.4.14-1.mga8
+ Revision: 1550288
- 4.4.14

* Thu Feb 20 2020 umeabot <umeabot> 4.4.12-2.mga8
+ Revision: 1546344
- Mageia 8 Mass Rebuild

* Sun Feb 02 2020 luigiwalser <luigiwalser> 4.4.12-1.mga8
+ Revision: 1486397
- 4.4.12
+ wally <wally>
- replace deprecated %%configure2_5x

* Thu Jan 02 2020 luigiwalser <luigiwalser> 4.4.10-1.mga8
+ Revision: 1475416
- 4.4.10

* Tue Aug 13 2019 tmb <tmb> 4.4.6-2.mga8
+ Revision: 1429146
- rebuild with gcc 9.2

* Mon May 13 2019 luigiwalser <luigiwalser> 4.4.6-1.mga7
+ Revision: 1397522
- 4.4.6

* Fri Mar 15 2019 tmb <tmb> 4.4.4-1.mga7
+ Revision: 1377597
- update to 4.4.4

* Thu Feb 07 2019 tmb <tmb> 4.4.3-1.mga7
+ Revision: 1364054
- update to 4.4.3

* Sun Dec 30 2018 luigiwalser <luigiwalser> 4.4.2-1.mga7
+ Revision: 1346914
- 4.4.2

* Mon Dec 03 2018 tmb <tmb> 4.4.0-1.mga7
+ Revision: 1338066
- update to 4.4.0

* Thu Nov 08 2018 tv <tv> 4.2.3-2.mga7
+ Revision: 1328853
- fix broken symlink doc in devel pkg

* Wed Nov 07 2018 tmb <tmb> 4.2.3-1.mga7
+ Revision: 1328794
- update to 4.2.3

* Thu Oct 11 2018 tmb <tmb> 4.2.1-1.mga7
+ Revision: 1319636
- update to 4.2.1

* Mon Sep 03 2018 daviddavid <daviddavid> 4.1.2-2.mga7
+ Revision: 1256347
- fix dangling link (mga#23515)

* Wed Aug 29 2018 tmb <tmb> 4.1.2-1.mga7
+ Revision: 1255525
- update filelist for added manpages
- update to 4.1.2

* Sat Aug 18 2018 wally <wally> 4.1.1-3.mga7
+ Revision: 1252492
- add more provides to devel pkg

* Wed Aug 08 2018 tmb <tmb> 4.1.1-2.mga7
+ Revision: 1250235
- conflict crypt enabled glibc packages

* Wed Aug 08 2018 tmb <tmb> 4.1.1-1.mga7
+ Revision: 1249772
- fix build
- fix groups
- adapt to mageia
- update to 4.1.1
- Import from OpenSUSE

